# vim: set sw=4 ts=4 et nu:
#
# spec file for package etckeeper
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Mitsutoshi NAKANO <bkbin005@rinku.zaq.ne.jp>
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# see https://en.opensuse.org/openSUSE:Packaging_Python#Compatibility_with_older_distributions
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
Name:           etckeeper
Version:        1.18.7
Release:        lp150.1.4
Summary:        Store /etc under Version Control
License:        GPL-2.0+
Group:          System/Management
Source:         https://git.joeyh.name/index.cgi/etckeeper.git/snapshot/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM etckeeper-avoid-packagelist.patch gh#joeyh/etckeeper#17 bkbin005@rinku.zaq.ne.jp -- add AVOID_PACKAGELIST
Patch0:         etckeeper-avoid-packagelist.patch
# PATCH-FIX-UPSTREAM 0001-Remove-env-from-shebang-in-zypper-plugin.patch
Patch1:         0001-Remove-env-from-shebang-in-zypper-plugin.patch
Url:            http://etckeeper.branchable.com/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define LPM rpm
Requires:       python-base >= 2.7
BuildRequires:  make
# added for bzr 2014-07-10 bkbin005@rinku.zaq.ne.jp
BuildRequires:  bzr
BuildRequires:  python-devel

%if 0%{?suse_version}
# modified 2014-07-09 bkbin005@rinku.zaq.ne.jp
# Users should be able to select VCS.
Recommends:     git
Recommends:     %{name}-cron = %{version}-%{release}
Recommends:     %{name}-zypp-plugin = %{version}-%{release}
BuildRequires:  libzypp
%define HPM zypper
%else
BuildRequires:  yum
Requires:       %{name}-cron = %{version}-%{release}
Requires:       %{name}-yum-plugin = %{version}-%{release}
%define HPM yum
%endif
%{?systemd_requires}

%description
The etckeeper program is a tool to let /etc be stored in a git,
mercurial, bzr or darcs repository. It hooks into yum to automatically
commit changes made to /etc during package upgrades. It tracks file
metadata that version control systems do not normally support, but that
is important for /etc, such as the permissions of /etc/shadow. It is
quite modular and configurable, while also being simple to use if you
understand the basics of working with version control.


%package cron
Summary:        The etckeeper cron function
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Provides:       etckeeper:%{_sysconfdir}/cron.daily/etckeeper
%if 0%{?suse_version}
Requires:       cron
%else
Requires:       crontabs
%endif

%description cron
The etckeeper-cron calls etckeeper from cron.


%if 0%{?suse_version}
%package zypp-plugin
Summary:        The etckeeper integration function with ZYpp
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Requires:       zypp-plugin-python
BuildRequires:  zypp-plugin-python
Obsoletes:      etckeeper-pkgmanager-collabo < %{version}-%{release}
Provides:       etckeeper-pkgmanager-collabo = %{version}-%{release}
Provides:       etckeeper:%{_prefix}/lib/zypp/plugins/commit/zypper-etckeeper.py

%description zypp-plugin
The etckeeper-zypp-plugin calls etckeeper from ZYpp.
%else
%package yum-plugin
Summary:        The etckeeper integration function with YUM
Group:          System/Management
Requires:       etckeeper = %{version}-%{release}
Obsoletes:      etckeeper-pkgmanager-collabo
Provides:       etckeeper-pkgmanager-collabo = %{version}-%{release}
Provides:       etckeeper:%{_sysconfdir}/yum/pluginconf.d/etckeeper.conf

%description yum-plugin
The etckeeper-zypp-plugin calls etckeeper from YUM.
%endif

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%__perl -pi -e '
s|^(\s*)(HIGHLEVEL_PACKAGE_MANAGER)=.+|$1$2=%{HPM}|;
s|^(\s*)(LOWLEVEL_PACKAGE_MANAGER)=.+|$1$2=%{LPM}|;
s|^(\s*)(VCS)=.+|$1$2=git|;
' ./etckeeper.conf

# rpmlint
find -type f -name ".gitignore" -delete
rm -f ./doc/todo/.mdwn

# use %%{_unitdir} for rpm-based distros
sed -i 's:systemddir=/lib/systemd/system:systemddir=%{_unitdir}:g' Makefile

%build
make %{?_smp_mflags}

%install
make \
    DESTDIR="%{buildroot}" \
    PYTHON_INSTALL_OPTS="--prefix=%{_prefix} --install-purelib=%{python_sitearch}" \
    install
install -D debian/cron.daily "%{buildroot}/etc/cron.daily/%{name}"

mkdir %{buildroot}%{_sbindir}
ln -s ../bin/%{name} %{buildroot}%{_sbindir}/%{name}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre etckeeper.service

%preun
%service_del_preun etckeeper.service

%post
%service_add_post etckeeper.service

%postun
%service_del_postun etckeeper.service

%files
%doc GPL README.md doc
%{_unitdir}/etckeeper*
%{_bindir}/etckeeper
%{_sbindir}/*etckeeper
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/etckeeper
%dir %{_sysconfdir}/etckeeper
%{_sysconfdir}/etckeeper/daily
%config(noreplace) %{_sysconfdir}/etckeeper/etckeeper.conf
%dir %{_sysconfdir}/etckeeper/*.d
%config %{_sysconfdir}/etckeeper/*.d/*
%doc %{_mandir}/man8/etckeeper.8*
%{python_sitearch}/bzrlib/plugins/%{name}/
%{python_sitearch}/bzr_%{name}-*.egg-info

%files cron
%config(noreplace) %{_sysconfdir}/cron.daily/etckeeper

%if 0%{?suse_version}
%files zypp-plugin
%{_prefix}/lib/zypp/plugins/commit/zypper-etckeeper.py
%else
%files yum-plugin
%config(noreplace) %{_sysconfdir}/yum/pluginconf.d/etckeeper.conf
%{_prefix}/lib/yum-plugins/etckeeper.*
%endif

%changelog
* Wed Oct 18 2017 aavindraa@gmail.com
- update to 1.18.7:
  * Will work on systems that don't have perl. (Perl is still used
    when available).
  * Prevent LC_ALL overriding the LC_COLLATE used to sort metadata.
- includes changes from 1.18.6:
  * Only show errors (no progress indicators) when pushing
    Git/Mercurial repos to avoid unecessary cron mails.
  * Fix regex in 20-warn-problem-files.
  * Support added for apk (alpine linux)
- Lint spec file
- Point source URL to upstream tarball
- Mark dependency on python-base per rpmlint
- Patches / source modifications:
  * Add 0001-Remove-env-from-shebang-in-zypper-plugin.patch
  - fixes rpmlint warning about dependency detection
  * Rebase etckeeeper-avoid-packagelist.patch
  * Remove junk file caught by rpmlint (.mdwn)
* Sat Oct 22 2016 jengelh@inai.de
- Remove redundant sections
* Sat Oct 15 2016 ecsos@opensuse.org
- update Source to 1.18.5:
  - Make etckeeper commit store metadata changes. The pre-commit
    hook has always (and continues) to do that, but pre-commit is
    only run when there are changes to tommit. This makes
    metadata-only changes get committed.
  - Move systemd files to /lib/systemd; /usr/lib/systemd is not
    used on Debian.
- fix wrong path for systemd in rpm based distros with sed in spec
* Sun Jul  3 2016 ecsos@opensuse.org
- update Source to 1.18.4:
  - Optimised find for special and hard linked files.
  - Adjust when Pacman 5 calls etckeeper hooks.
  - Only run Pacman hooks when files in /etc have changed.
  - Added systemd timer that can run etckeeper 10 minutes after boot, and also
    daily. It's not enabled by default, partly because of overlap with the
    cron job.
- update Source to 1.18.3:
  - Added support for pacmatic, contributed by nicolaichuk.
  - bzr: make sure EMAIL is defined
  - Fix Makefile version patterns to ignore non-native version number
  - Support ~/.config/git/config when determining the author name and email.
  - Added support for Arch's pacman package manager version 5.
  - Set HOME if it's not set, as is the case when using ubuntu's
    update-manager.
  - Move bash completion out of etc and into usr.
- update Source to 1.18.2:
  - Use getent utility instead of perl. (Elan Ruusamäe)
  - Initial FreeBSD support with pkgng plugin. (William Johansson)
  - Fix README.md symlink in package (Sebastian Schmidt, Antoine Beaupré,
    closes: #791566)
  - Fix typo of GIT_COMMITTER_EMAIL.
- update Source to 1.18.1
  - Add myself as maintainer (Closes: #768516)
  - Keeping the package native as I do not intend to diverge from
    upstream.
  - Update git URL in control file.
- update to Sourcce to 1.18:
  - Send yum pre-commit output to /dev/null
  - Set LANG=C internally when doing some operations that have
    been reported to fail in other locales.
- update Source to 1.17:
  - Fix name of DNF plugin.
  - Add --version
    Thanks Andreas Wansner.
  - New website, http://etckeeper.branchable.com/
  - Add build-depends on dh-python.
- update Source to 1.16:
  - Added support for Fedora's DNF highlevel package manager.
  - Add architecture info to dpkg list-installed. Closes: #768145
  - Orphaned the Debian package.
- rebase patch etckeeper-avoid-packagelist.patch
- change source url to github
- remove unnecessary file etckeeper-rpmlintrc
* Fri Jun  3 2016 ecsos@opensuse.org
- update Source to 1.15:
  - Recommend cron-daemon, rather than cron, as etckeeper only needs
    cron.daily functionality. Closes: #762721
- update Source to 1.14:
  - Handle failure to commit in post-install, pre-install by showing a
    warning, rather than propigating the error to apt.
    This avoids breaking the apt run when eg, git is misconfigured and
    cannot commit.
    pre-install already did this when it was able to use debconf to display a
    message, but now debconf is not used, and it always behaves this way.
    Closes: #760011
- change to new url
* Mon Aug 18 2014 bkbin005@rinku.zaq.ne.jp
- renamed to etckeeper-rpmlintrc from etckeeper.rpmlintrc:
  To follow the packaging guidelines.
  Please see also:
  https://build.opensuse.org/request/show/244964#request_history
  http://lists.opensuse.org/opensuse-packaging/2007-07/msg00000.html
* Fri Aug 15 2014 bkbin005@rinku.zaq.ne.jp
- updated Source to 1.13:
  + Ignore check-mk-agent-logwatch's FHS violating
    /etc/check_mk/logwatch.state. Closes: deb#753903
  + Only allow [-a-z_] in etckeeper commands to avoid any possible
    directory traversal etc issues.
  + update-ignore, uninit: Fix parsing of ignore files containing '\'
- added etckeeper-avoid-packagelist.patch:
  Because it is slow that some package manager make the packagelist
  (eg, rpm -qa), high-level package manager might time out
  (eg. zypper in/remove).
  So I added this patch.
  If you think that the packagelist is unnecessary,
  set AVOID_PACKAGELIST=1 in etckeeper.conf.
  Or if you want to avoid it temporarily,
  you can use environment variable ETCKEEPER_AVOID_PACKAGELIST=1 .
  (eg, ETCKEEPER_AVOID_PACKAGELIST=1 zypper update).
  This patch was sent to upstream, but Joey does not accept it yet.
  Please see also gh#joeyh/etckeeper#17 .
- rename subpackage from pkgmanager-collabo
  to zypp-plugin or yum-plugin.
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-07/msg00060.html
- added "Provides:" for renaming:
  pkgmanager-collabo => (zypp|yum)-plugin.
  Please see also:
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_packageage
- added "Provides:" for split packages: etekeeper-cron and plugins.
  Please see also:
  https://en.opensuse.org/openSUSE:Package_dependencies#Splitting_off_a_sub-pack
- added "Reccomends: git".
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-07/msg00060.html
- added bzr support files.
  Their files need "Buildrequires: python-devel bzr",
  but did not write them, so they were not installed untill now.
- added Python Compatibility with older distributions codes.
  Please see also:
  https://en.opensuse.org/openSUSE:Packaging_Python#Compatibility_with_older_distributions
- added version-release number to Recommendes and Requires.
  It is desirable that etckeeper packages are same version.
- removed lib/zypp directories:
  They should belong libzypp.
  + remove them.
  + added "BuildRequire: zypp-plugin-python".
* Mon Jul  7 2014 bkbin005@rinku.zaq.ne.jp
- modified etckeeper.spec style
  by "osc service run format_spec_file".
- removed lint code 'rm -rf "%%{buildroot}%%{_prefix}/lib"/python*'.
  This line does not work.
- removed "Requires: git".
  users can select VCS.
- divide etckeeper package into 3.
  + etckeeper:
    main function.
  + etckeeper-cron:
    cron function.
  + etckeeper-pkgmanager-collabo:
    collaboration with package manager.
- fix (bnc#884154): forgot to reqire zypp-plugin-python.
* Wed Jul  2 2014 bkbin005@rinku.zaq.ne.jp
- fix (bnc#884154).  change permission and locale.
  + added etckeeper-zypp.patch
    1) changed zypper-etckeeper.py 's permission from 644 to 755
    (in Makefile).
    2) in zypper-etckeeper.py set LANG to C.
  please see also:
  http://lists.opensuse.org/archive/opensuse-factory/2014-06/msg00090.html
- version up to 1.12 from 1.7
  + README's filename changed from README to README.md.
  + fix some bugs.
  + fix some typos.
  for detail,
  please do "git clone git://git.kitenet.net/etckeeper.git"
  and "git log".
* Wed Aug 21 2013 dvaleev@suse.com
- don't require git to build
- relax git version requirement
* Sat Aug 10 2013 pascal.bleser@opensuse.org
- initial version (1.7)
